@@ -332,6 +332,24 @@ class StorageDomainManifest(object):
         """
         raise NotImplementedError
 
+    @property
+    def supportsSparseness(self):
+        """
+        This property advertises whether the storage domain supports
+        sparseness or not.
+        """
+        return False
+
+    def recommends_unordered_writes(self, format):
+        """
+        Return True if unordered writes are recommended for copying an image
+        using format to this storage domain.
+
+        Unordered writes improve copy performance but are recommended only for
+        preallocated devices and raw format.
+        """
+        return format == sc.RAW_FORMAT and not self.supportsSparseness
+
     @property
     def oop(self):
         return oop.getProcessPool(self.sdUUID)
@@ -730,7 +748,10 @@ class StorageDomain(object):
         This property advertises whether the storage domain supports
         sparseness or not.
         """
-        return False
+        return self._manifest.supportsSparseness
+
+    def recommends_unordered_writes(self, format):
+        return self._manifest.recommends_unordered_writes(format)
 
     @property
     def oop(self):
