@@ -1,5 +1,5 @@
 #
-# Copyright 2016-2017 Red Hat, Inc.
+# Copyright 2016-2018 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,26 +23,21 @@ import logging
 
 import six
 
-from vdsm.network.nm import networkmanager
-
 from testlib import mock
 
 from .nettestlib import bonding_default_fpath
-from .nettestlib import nm_is_running
+from .ovsnettestlib import OvsService
 from . ip_rule_test import IPV4_ADDRESS1, IPRuleTest
 
 
 bonding_dump_patchers = []
-network_manager_patcher = None
+ovs_service = None
 
 
 def setup_package():
-    global network_manager_patcher
-    network_manager_patcher = mock.patch(
-        'vdsm.network.nm.networkmanager.is_running', nm_is_running)
-    network_manager_patcher.start()
-    if networkmanager.is_running():
-        networkmanager.init()
+    global ovs_service
+    ovs_service = OvsService()
+    ovs_service.setup()
 
     bonding_defaults, bonding_name2numeric = bonding_default_fpath()
     bonding_dump_patchers.append(
@@ -61,12 +56,12 @@ def teardown_package():
     for patcher in bonding_dump_patchers:
         patcher.stop()
 
-    network_manager_patcher.stop()
-
     # TODO: Remove condition when ip.rule becomes PY3 compatible.
     if six.PY2:
         _cleanup_stale_iprules()
 
+    ovs_service.teardown()
+
 
 class StaleIPRulesError(Exception):
     pass
